@@ -3,8 +3,9 @@
 @Date: 2025/4/11 14:59
 """
 import kytest
+from kytest.core.ios import Elem
 
 
 class IosPage(kytest.Page):
-    music_tab = kytest.IosElem(label='儿童')
-    gold_tab = kytest.IosElem(name='金币')
+    music_tab = Elem(label='儿童')
+    gold_tab = Elem(name='金币')
