@@ -2,8 +2,7 @@
 @Author: kang.yang
 @Date: 2024/7/12 17:10
 """
-import kytest
-from kytest import AppConfig
+from kytest import AppConfig, main
 
 
 if __name__ == '__main__':
@@ -12,7 +11,7 @@ if __name__ == '__main__':
     AppConfig.wda_project_path = '/Users/UI/Downloads/WebDriverAgent-master/WebDriverAgent.xcodeproj'
     AppConfig.run_mode = 'full'
 
-    kytest.main(path="tests/test_ios.py")
+    main(path="tests/test_ios.py")
 
 
 
