@@ -1,28 +1,29 @@
 import kytest
+from kytest.core.adr import TC
 from page.adr_page import AdrPage
 
 
 @kytest.story('测试demo')
-class TestAdrDemo(kytest.AdrTC):
+class TestAdrDemo(TC):
     def start(self):
         self.start_app()
-        self.adr = AdrPage(self.dr)
+        self.AP = AdrPage(self.dr)
 
     def end(self):
         self.stop_app()
 
     @kytest.title('进入我的页')
     def test_switch_to_my(self):
-        if self.adr.ad_btn.exists():
-            self.adr.ad_btn.click()
-        self.adr.my_tab.click()
+        if self.AP.ad_btn.exists():
+            self.AP.ad_btn.click()
+        self.AP.my_tab.click()
         self.sleep(5)
 
     @kytest.title('进入科创空间')
     def test_switch_to_space(self):
-        if self.adr.ad_btn.exists():
-            self.adr.ad_btn.click()
-        self.adr.space_tab.click()
+        if self.AP.ad_btn.exists():
+            self.AP.ad_btn.click()
+        self.AP.space_tab.click()
         self.sleep(5)
 
 
