@@ -2,21 +2,21 @@
 @Author: kang.yang
 @Date: 2024/10/8 15:12
 """
-import kytest
+from kytest.core.hm import TC
 from page.hm_page import HmPage
 
 
-class TestHmDemo(kytest.HmTC):
+class TestHmDemo(TC):
 
     def start(self):
         self.start_app()
-        self.hm = HmPage(self.dr)
+        self.HP = HmPage(self.dr)
 
     def test_hm(self):
         self.dr.click(630, 2050)
-        self.hm.my_entry.click()
-        self.hm.login_entry.click()
-        assert self.hm.pwd_login.exists()
+        self.HP.my_entry.click()
+        self.HP.login_entry.click()
+        assert self.HP.pwd_login.exists()
 
 
 
