@@ -1,3 +1,4 @@
+
 from .running.runner import (
     main,
     ApiConfig,
@@ -13,10 +14,7 @@ from .utils.pytest_util import *
 from .utils.allure_util import *
 from .utils.log import logger
 from .core.api import HttpReq, TC
-from .core.adr import AdrTC, AdrElem
-from .core.ios import IosTC, IosElem
-from .core.web import WebTC, WebElem
-from .core.hm import HmTC, HmElem
 
-__version__ = "0.2.8"
+
+__version__ = "0.2.12"
 __description__ = "API/安卓/IOS/WEB/鸿蒙Next平台自动化测试框架"
