@@ -1,57 +1,60 @@
 import typing
+from .driver import Driver
 
+from kytest.running.conf import App
 from kytest.utils.log import logger
+from kytest.utils.config import FileConfig
 from uiautomator2 import UiObject
 from uiautomator2.xpath import XPathSelector
 
 
-# 链式调用临时存储定位方式
-class ChildLocator:
-
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        self.kwargs = kwargs
-        self.type = 'child'
-
-
-class SiblingLocator:
-
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        self.kwargs = kwargs
-        self.type = 'sibling'
-
-
-class LeftLocator:
-
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        self.kwargs = kwargs
-        self.type = 'left'
-
-
-class RightLocator:
-
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        self.kwargs = kwargs
-        self.type = 'right'
-
-
-class UpLocator:
-
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        self.kwargs = kwargs
-        self.type = 'up'
-
-
-class DownLocator:
-
-    def __init__(self, *args, **kwargs):
-        self.args = args
-        self.kwargs = kwargs
-        self.type = 'down'
+# # 链式调用临时存储定位方式
+# class ChildLocator:
+#
+#     def __init__(self, *args, **kwargs):
+#         self.args = args
+#         self.kwargs = kwargs
+#         self.type = 'child'
+#
+#
+# class SiblingLocator:
+#
+#     def __init__(self, *args, **kwargs):
+#         self.args = args
+#         self.kwargs = kwargs
+#         self.type = 'sibling'
+#
+#
+# class LeftLocator:
+#
+#     def __init__(self, *args, **kwargs):
+#         self.args = args
+#         self.kwargs = kwargs
+#         self.type = 'left'
+#
+#
+# class RightLocator:
+#
+#     def __init__(self, *args, **kwargs):
+#         self.args = args
+#         self.kwargs = kwargs
+#         self.type = 'right'
+#
+#
+# class UpLocator:
+#
+#     def __init__(self, *args, **kwargs):
+#         self.args = args
+#         self.kwargs = kwargs
+#         self.type = 'up'
+#
+#
+# class DownLocator:
+#
+#     def __init__(self, *args, **kwargs):
+#         self.args = args
+#         self.kwargs = kwargs
+#         self.type = 'down'
 
 
 class Elem(object):
@@ -60,7 +63,7 @@ class Elem(object):
     https://github.com/openatx/uiautomator2
     """
 
-    def __init__(self, driver=None, watch: list = None, **kwargs):
+    def __init__(self, driver: Driver = None, watch: list = None, **kwargs):
         """
         @param driver: 安卓驱动
         @param watch: 需要处理的异常弹窗定位方式列表
@@ -69,7 +72,16 @@ class Elem(object):
         self._driver = driver
         self._xpath = kwargs.get('xpath', None)
         self._watch = watch
-        self.locators = []
+        # self.locators = []
+        if 'rid' in self._kwargs:
+            self._kwargs['resourceId'] = self._kwargs.pop('rid')
+        self._pkg = App.pkg
+        if 'resourceId' in self._kwargs:
+            if not self._kwargs['resourceId'].startswith(self._pkg):
+                if not self._pkg:
+                    raise KeyError('应用包名不能为空')
+                else:
+                    self._kwargs['resourceId'] = self._pkg + ":" + self._kwargs['resourceId']
 
     def __get__(self, instance, owner):
         """po模式中element初始化不需要带driver的关键"""
@@ -79,30 +91,30 @@ class Elem(object):
         self._driver = instance.driver
         return self
 
-    # 链式调用方法
-    def child(self, *args, **kwargs):
-        self.locators.append(ChildLocator(*args, **kwargs))
-        return self
-
-    def sibling(self, *args, **kwargs):
-        self.locators.append(SiblingLocator(*args, **kwargs))
-        return self
-
-    def left(self, *args, **kwargs):
-        self.locators.append(LeftLocator(*args, **kwargs))
-        return self
-
-    def right(self, *args, **kwargs):
-        self.locators.append(RightLocator(*args, **kwargs))
-        return self
-
-    def up(self, *args, **kwargs):
-        self.locators.append(UpLocator(*args, **kwargs))
-        return self
-
-    def down(self, *args, **kwargs):
-        self.locators.append(DownLocator(*args, **kwargs))
-        return self
+    # # 链式调用方法
+    # def child(self, *args, **kwargs):
+    #     self.locators.append(ChildLocator(*args, **kwargs))
+    #     return self
+    #
+    # def sibling(self, *args, **kwargs):
+    #     self.locators.append(SiblingLocator(*args, **kwargs))
+    #     return self
+    #
+    # def left(self, *args, **kwargs):
+    #     self.locators.append(LeftLocator(*args, **kwargs))
+    #     return self
+    #
+    # def right(self, *args, **kwargs):
+    #     self.locators.append(RightLocator(*args, **kwargs))
+    #     return self
+    #
+    # def up(self, *args, **kwargs):
+    #     self.locators.append(UpLocator(*args, **kwargs))
+    #     return self
+    #
+    # def down(self, *args, **kwargs):
+    #     self.locators.append(DownLocator(*args, **kwargs))
+    #     return self
 
     # 公共方法
     def watch_handler(self):
@@ -129,22 +141,22 @@ class Elem(object):
         _element = self._driver.d.xpath(self._xpath) if \
             self._xpath is not None else self._driver.d(**self._kwargs)
 
-        # 链式调用方法叠加
-        if self.locators:
-            logger.info(f"链式调用: {self.locators}")
-            for loc_obj in self.locators:
-                if loc_obj.type == "child":
-                    _element = _element.child(*loc_obj.args, **loc_obj.kwargs)
-                elif loc_obj.type == 'sibling':
-                    _element = _element.sibling(*loc_obj.args, **loc_obj.kwargs)
-                elif loc_obj.type == 'left':
-                    _element = _element.left(*loc_obj.args, **loc_obj.kwargs)
-                elif loc_obj.type == 'right':
-                    _element = _element.right(*loc_obj.args, **loc_obj.kwargs)
-                elif loc_obj.type == 'up':
-                    _element = _element.up(*loc_obj.args, **loc_obj.kwargs)
-                elif loc_obj.type == 'down':
-                    _element = _element.down(*loc_obj.args, **loc_obj.kwargs)
+        # # 链式调用方法叠加
+        # if self.locators:
+        #     logger.info(f"链式调用: {self.locators}")
+        #     for loc_obj in self.locators:
+        #         if loc_obj.type == "child":
+        #             _element = _element.child(*loc_obj.args, **loc_obj.kwargs)
+        #         elif loc_obj.type == 'sibling':
+        #             _element = _element.sibling(*loc_obj.args, **loc_obj.kwargs)
+        #         elif loc_obj.type == 'left':
+        #             _element = _element.left(*loc_obj.args, **loc_obj.kwargs)
+        #         elif loc_obj.type == 'right':
+        #             _element = _element.right(*loc_obj.args, **loc_obj.kwargs)
+        #         elif loc_obj.type == 'up':
+        #             _element = _element.up(*loc_obj.args, **loc_obj.kwargs)
+        #         elif loc_obj.type == 'down':
+        #             _element = _element.down(*loc_obj.args, **loc_obj.kwargs)
 
         if self._watch:
             self.watch_handler()
