@@ -1,12 +1,13 @@
-from .elem import Elem as IosElem
+# # pip install kytest[ios]
+from .elem import Elem
 from .remote_driver import RemoteDriver
 from .local_driver import Driver
-from .case import TestCase as IosTC
+from .case import TestCase as TC
 
 __all__ = [
-    "IosElem",
+    "Elem",
     "RemoteDriver",
     "Driver",
-    "IosTC",
+    "TC",
 ]
 
