@@ -170,7 +170,7 @@ class Elem(object):
         logger.info(f"判断控件{self._kwargs}是否存在")
         result = False
         try:
-            _element = self.find(timeout=timeout)
+            _element = self.find(timeout=timeout, n=0)
             result = True
         except:
             result = False
