@@ -146,3 +146,47 @@ class Driver(object):
 
     def unlock(self):
         self.d.unlock()
+
+    def _match(self, text):
+        """
+        判断元素是否存在当前页面
+        @return:
+        """
+        _element = self.d(text=text)
+        result = text if _element.wait(timeout=0.1,
+                                       raise_error=False) else None
+        return result
+
+    def pop_check(self, watch_list: list, timeout=3):
+        logger.info(f"开始弹窗检测: {watch_list}")
+        # 多线程match，如果match到，获取第一个非None内容，进行点击
+        # match完休息1s，如果休息3s也没有match到，就停止（定义一个flag，match到就清零）
+        # 如果3s内仍然能match到就继续（如果flag大于3就停止）
+        _build_info = ["允许", "使用App时允许", "始终允许"]
+        if watch_list is True:
+            loc_list = _build_info
+        else:
+            loc_list = list(set(_build_info + watch_list))
+        flag = timeout
+        while flag > 0:
+            import concurrent.futures
+
+            logger.info(f"匹配: {loc_list}")
+            with concurrent.futures.ThreadPoolExecutor() as executor:
+                results = executor.map(self._match, loc_list)
+                results = [item for item in results if item is not None]
+
+            if results:
+                logger.info(f"匹配到: {results}")
+                try:
+                    self.d(text=results[0]).click_exists(timeout=1)
+                except:
+                    pass
+                logger.info("点击成功")
+                flag = timeout
+            else:
+                logger.info("匹配失败")
+
+            flag -= 1
+            time.sleep(1)
+        logger.info("结束检测")
